<?php

/**
 * @file
 * Custom header content type.
 *
 * This content type is nothing more than a header title and optional URL.
 * The information is stored right in the config, so each custom header is
 * unique.
 */

/**
 * Callback function to supply a list of content types.
 */
function panels_header_panels_header_pane_ctools_content_types() {
  return array(
    'title' => t('New custom header'),
    'description' => t('Create a header pane (requires and uses no context).'),
    'icon' => 'icon_block_custom.png',
    'single' => TRUE,
    'content_types' => array('panels_header_pane'),
    'render callback' => 'panels_header_pane_render',
    'edit form' => 'panels_header_pane_edit_form',
    // Make this a top level category so it appears higher in UIs that support
    // that.
    'top level' => TRUE,
    'category' => t('Custom'),
    'defaults' => array(
      'header' => '',
      'url' => '',
    ),
    'no title override' => TRUE,
  );
}

/**
 * Run-time rendering of the panels header pane.
 *
 * @param $subtype
 * @param $conf
 *   Configuration as done at admin time.
 * @param $args
 * @param $context
 *   Context - in this case we don't have any.
 *
 * @return
 *   An object with at least title and content members.
 */
function panels_header_pane_render($subtype, $conf, $args, $context) {
  $block = new stdClass();
  $block->content = theme('panels_header_pane', $conf);
  // $block->title is intentionally left blank.
  return $block;
}

/**
 * 'Edit form' callback for the panels header pane type.
 */
function panels_header_pane_edit_form(&$form, &$form_state) {
  $conf = $form_state['conf'];
  $form['header'] = array(
    '#type' => 'textfield',
    '#default_value' => isset($conf['header']) ? $conf['header'] : '',
    '#title' => t('Header'),
  );
  $form['url'] = array(
    '#type' => 'textfield',
    '#default_value' => isset($conf['url']) ? $conf['url'] : '',
    '#description' => t('If you want this header to link to something, type the URL here. This can be either a drupal path (e.g. %drupal_path) or an absolute url (e.g. %absolute_path).', array('%drupal_path' => 'node/1', '%absolute_path' => 'http://example.com/node/1')),
    '#title' => t('URL'),
  );
  return $form;
}

function panels_header_pane_edit_form_submit(&$form, &$form_state) {
  foreach (array('header', 'url') as $key) {
    $form_state['conf'][$key] = $form_state['values'][$key];
  }
}

/**
 * Callback to provide the administrative title of the custom header.
 */
function panels_header_panels_header_pane_content_type_admin_title($subtype, $conf) {
  $output = t('Header');
  /// @todo: It'd might nice to display these, but they don't live in $conf.
/*
  if (!empty($conf['css_id'])) {
    $output .= ' {' . check_plain($conf['css_id']) . '}';
  }
  if (!empty($conf['css_class'])) {
    $output .= ' {' . check_plain($conf['css_class']) . '}';
  }
*/
  if (!empty($conf['url'])) {
    $output .= ' [' . check_plain($conf['url']) . ']';
  }
  return $output;
}

/**
 * Callback to provide administrative info for the custom header.
 */
function panels_header_panels_header_pane_content_type_admin_info($subtype, $conf) {
  $block = new stdClass();
  $block->title = check_plain($conf['header']);
  $block->content = !empty($conf['url']) ? l($conf['url'], $conf['url']) : '';
  return $block;
}
